"""SQL branch — free SQL queries returning native DataFrames.

Two main branches in tacoreader:
    sql/   → ds.sql(query) → DataFrame  (this package)
    nav/   → ds.filter_*() → TacoDataset
"""

from tacoreader.sql.executor import execute_sql

__all__ = ["execute_sql"]